#!/bin/bash

DOMAIN="example.com"
BASESUBDOMAIN="test"
BASEDAYS=365
BASESUBJECT="/C=TH/ST=Bangkok/L=Thungmahamek"

# create 10-year CA key/cert pair
openssl genrsa -out rootCA.key 4096
openssl req -x509 -new -nodes -key rootCA.key -sha256 -days $(($BASEDAYS*10)) -out rootCA.crt -subj "${BASESUBJECT}/O=Test CA/CN=Test CA"

# create SAN config files, keys, CSRs and certificates for our 5 test subdomains
for i in $(seq 1 5);
do
    CN="${BASESUBDOMAIN}${i}.${DOMAIN}"
    cat <<EOF > ${CN}.cnf
[req]
distinguished_name = req_distinguished_name
req_extensions = v3_req

[req_distinguished_name]

[ v3_req ]
subjectAltName = @alt_names

[alt_names]
DNS.1 = ${CN}
DNS.2 = www.${CN}
EOF
    # generate 4096-bit RSA key
    openssl genrsa -out ${CN}.key 4096
    # generate CSR
    openssl req -out ${CN}.csr -key ${CN}.key -new -nodes -subj "${BASESUBJECT}/O=Test ${i}/CN=${CN}" -config ./${CN}.cnf
    # sign and create certificate
    echo "Generating certificate for $CN with $(($BASEDAYS/$i)) days validity"
    openssl x509 -req -in ${CN}.csr -CA rootCA.crt -CAkey rootCA.key -CAcreateserial -out ${CN}.crt -days $(($BASEDAYS/$i)) -sha256 -extfile ${CN}.cnf -extensions v3_req
done
